firewall {
    all-ping enable
    broadcast-ping disable
    group {
        network-group PRIVATE_NETS {
            network 192.168.0.0/16
            network 172.16.0.0/12
            network 10.0.0.0/8
        }
        network-group elisa {
            description ""
            network 85.0.0.0/8
        }
    }
    ipv6-receive-redirects disable
    ipv6-src-route disable
    ip-src-route disable
    log-martians disable
    modify balance {
        rule 10 {
            action modify
            description "do NOT load balance lan to lan"
            destination {
                group {
                    network-group PRIVATE_NETS
                }
            }
            modify {
                table main
            }
        }
        rule 30 {
            action modify
            description "do NOT load balance destination public address"
            destination {
                group {
                    address-group ADDRv4_eth1
                }
            }
            modify {
                table main
            }
        }
        rule 40 {
            action modify
            description "do NOT load balance destination public address"
            destination {
                group {
                    address-group ADDRv4_eth2
                }
            }
            modify {
                table main
            }
        }
        rule 140 {
            action modify
            modify {
                lb-group G
            }
        }
    }
    name WAN_IN {
        default-action drop
        description "WAN to internal"
        rule 10 {
            action accept
            application {
                category Web
            }
            description webserver
            destination {
                address 10.20.20.78
                port 80
            }
            log disable
            protocol tcp
            state {
                established enable
                invalid disable
                new enable
                related enable
            }
        }
        rule 20 {
            action accept
            description webservers
            destination {
                address 10.20.20.78
                port 443
            }
            log enable
            protocol tcp
        }
        rule 30 {
            action accept
            description "Allow established/related"
            state {
                established enable
                related enable
            }
        }
        rule 40 {
            action drop
            description "Drop invalid state"
            state {
                invalid enable
            }
        }
    }
    name WAN_LOCAL {
        default-action drop
        description "WAN to router"
        rule 10 {
            action accept
            description "Allow established/related"
            state {
                established enable
                related enable
            }
        }
        rule 20 {
            action drop
            description "Drop invalid state"
            state {
                invalid enable
            }
        }
    }
    receive-redirects disable
    send-redirects enable
    source-validation disable
    syn-cookies enable
}
interfaces {
    bridge br0 {
        aging 300
        bridged-conntrack disable
        hello-time 2
        max-age 20
        priority 32768
        promiscuous disable
        stp false
        vif 10 {
            address 10.10.0.1/16
            description cumulus
        }
        vif 20 {
            address 10.20.0.1/16
            description admin
        }
        vif 30 {
            address 10.30.0.1/16
            description iot
        }
        vif 40 {
            address 10.40.0.1/16
            description office
        }
    }
    ethernet eth0 {
        duplex auto
        speed auto
    }
    ethernet eth1 {
        address dhcp
        description WAN
        duplex auto
        firewall {
            in {
                name WAN_IN
            }
            local {
                name WAN_LOCAL
            }
        }
        speed auto
    }
    ethernet eth2 {
        address dhcp
        description WAN2
        duplex auto
        firewall {
            in {
                name WAN_IN
            }
            local {
                name WAN_LOCAL
            }
        }
        speed auto
    }
    ethernet eth3 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    ethernet eth4 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    ethernet eth5 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    ethernet eth6 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    ethernet eth7 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    ethernet eth8 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    ethernet eth9 {
        bridge-group {
            bridge br0
        }
        duplex auto
        poe {
            output off
        }
        speed auto
    }
    ethernet eth10 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    ethernet eth11 {
        bridge-group {
            bridge br0
        }
        duplex auto
        speed auto
    }
    switch switch0 {
        address 192.168.1.1/24
        description Local
        firewall {
            in {
                modify balance
            }
        }
        mtu 1500
        switch-port {
            interface eth0 {
            }
            vlan-aware disable
        }
    }
}
load-balance {
    group G {
        exclude-local-dns disable
        flush-on-active enable
        gateway-update-interval 20
        interface eth1 {
        }
        interface eth2 {
        }
        lb-local enable
        lb-local-metric-change disable
    }
}
service {
    dhcp-server {
        disabled false
        hostfile-update disable
        shared-network-name LAN {
            authoritative enable
            subnet 192.168.1.0/24 {
                default-router 192.168.1.1
                dns-server 192.168.1.1
                lease 86400
                start 192.168.1.38 {
                    stop 192.168.1.243
                }
            }
        }
        shared-network-name admin {
            authoritative disable
            subnet 10.20.0.0/16 {
                default-router 10.20.0.1
                dns-server 1.1.1.1
                lease 86400
                start 10.20.20.20 {
                    stop 10.20.40.40
                }
                static-mapping 1_cafe_115_eap {
                    ip-address 10.20.20.35
                    mac-address b0:a7:b9:ee:af:c5
                }
                static-mapping 1_earth_110_eap {
                    ip-address 10.20.20.26
                    mac-address 00:31:92:d1:e1:f9
                }
                static-mapping 1_lounge_115_eap {
                    ip-address 10.20.20.24
                    mac-address b0:a7:b9:ee:af:c8
                }
                static-mapping 1_stair_115_eap {
                    ip-address 10.20.20.31
                    mac-address 60:a4:b7:20:1f:85
                }
                static-mapping 2__stair_115_eap {
                    ip-address 10.20.20.23
                    mac-address b0:a7:b9:ee:af:e1
                }
                static-mapping 3_stair_115_eap {
                    ip-address 10.20.20.28
                    mac-address 60:a4:b7:20:1e:6d
                }
                static-mapping 4_stair_115_eap {
                    ip-address 10.20.20.29
                    mac-address b0:a7:b9:ee:af:dc
                }
                static-mapping 5_a_hissi_110_eap {
                    ip-address 10.20.20.27
                    mac-address 90:9a:4a:80:1c:f6
                }
            }
        }
        shared-network-name cumulus {
            authoritative disable
            subnet 10.10.0.0/16 {
                default-router 10.10.0.1
                dns-server 1.1.1.1
                lease 86400
                start 10.10.0.10 {
                    stop 10.10.10.0
                }
            }
        }
        shared-network-name iot {
            authoritative disable
            subnet 10.30.0.0/16 {
                default-router 10.30.0.1
                dns-server 1.1.1.1
                lease 86400
                start 10.30.30.10 {
                    stop 10.30.40.1
                }
            }
        }
        shared-network-name office {
            authoritative disable
            subnet 10.40.0.0/16 {
                default-router 10.40.0.1
                dns-server 1.1.1.1
                lease 86400
                start 10.40.40.10 {
                    stop 10.40.50.1
                }
            }
        }
        static-arp disable
        use-dnsmasq disable
    }
    dns {
        forwarding {
            cache-size 10000
            listen-on switch0
        }
    }
    gui {
        http-port 80
        https-port 443
        older-ciphers enable
    }
    mdns {
        reflector
        repeater {
            interface br0.20
            interface br0.30
            interface br0.40
        }
    }
    nat {
        rule 1 {
            description wan1http
            destination {
                group {
                    network-group elisa
                }
                port 80
            }
            inbound-interface eth1
            inside-address {
                address 10.20.20.78
                port 80
            }
            log enable
            protocol tcp
            source {
            }
            type destination
        }
        rule 2 {
            description wan2http
            destination {
                group {
                    network-group elisa
                }
                port 80
            }
            inbound-interface eth2
            inside-address {
                address 10.20.20.78
                port 80
            }
            log enable
            protocol tcp
            source {
            }
            type destination
        }
        rule 3 {
            description wan1https
            destination {
                address 85.76.133.88
                port 443
            }
            inbound-interface eth1
            inside-address {
                address 10.20.20.78
                port 443
            }
            log enable
            protocol tcp
            source {
            }
            type destination
        }
        rule 4 {
            description wan2https
            destination {
                address 85.76.133.88
                port 443
            }
            inbound-interface eth2
            inside-address {
                address 10.20.20.78
                port 443
            }
            log enable
            protocol tcp
            source {
            }
            type destination
        }
        rule 5002 {
            description "masquerade for WAN"
            outbound-interface eth1
            type masquerade
        }
        rule 5004 {
            description "masquerade for WAN 2"
            outbound-interface eth2
            type masquerade
        }
    }
    ssh {
        port 22
        protocol-version v2
    }
    unms {
        disable
    }
}
system {
    analytics-handler {
        send-analytics-report false
    }
    conntrack {
        expect-table-size 4096
        hash-size 4096
        table-size 32768
        tcp {
            half-open-connections 512
            loose enable
            max-retrans 3
        }
    }
    crash-handler {
        send-crash-report false
    }
    host-name EdgeRouter
    login {
        user feenix {
            authentication {
                encrypted-password $5$ueL/kkCEaN/0gNUW$ukLH2Nge748HRAkQH1u6vfA3W9DfLqpXyovs3LYzOf9
            }
            level admin
        }
    }
    ntp {
        server 0.ubnt.pool.ntp.org {
        }
        server 1.ubnt.pool.ntp.org {
        }
        server 2.ubnt.pool.ntp.org {
        }
        server 3.ubnt.pool.ntp.org {
        }
    }
    syslog {
        global {
            facility all {
                level notice
            }
            facility protocols {
                level debug
            }
        }
    }
    time-zone Europe/Helsinki
    traffic-analysis {
        dpi disable
        export disable
    }
}


/* Warning: Do not remove the following line. */
/* === vyatta-config-version: "config-management@1:conntrack@1:cron@1:dhcp-relay@1:dhcp-server@4:firewall@5:ipsec@5:nat@3:qos@1:quagga@2:suspend@1:system@5:ubnt-l2tp@1:ubnt-pptp@1:ubnt-udapi-server@1:ubnt-unms@2:ubnt-util@1:vrrp@1:vyatta-netflow@1:webgui@1:webproxy@1:zone-policy@1" === */
/* Release version: v2.0.9-hotfix.2.5402463.210511.1317 */
